@@ -24,10 +24,12 @@ test_that("abcd_demo$company_id is of type character, as promised", {
   expect_type(abcd_demo$company_id, "character")
 })
 
-test_that("abcd_demo$company_id is unique to `name_company` and `sector`", {
-  out <- abcd_demo[c("company_id", "name_company", "sector")]
-  out <- unique(out)
-  out <- out$company_id[duplicated(out$company_id)]
-
-  expect_length(out, 0L)
-})
+# this is currently undesirable: a single unique company should be able to have
+# data in multiple sectors
+# test_that("abcd_demo$company_id is unique to `name_company` and `sector`", {
+#   out <- abcd_demo[c("company_id", "name_company", "sector")]
+#   out <- unique(out)
+#   out <- out$company_id[duplicated(out$company_id)]
+#
+#   expect_length(out, 0L)
+# })
